Learn R Programming

RChest (version 1.0.3)

list_estimator: list_estimator

Description

Returns the position of changepoints in the sequence. NOTE: PyChest needs to be installed first by calling `install_PyChest'.

Usage

list_estimator(sample, minimum_distance)

Arguments

sample

A vector of floats corresponding to the piecewise stationary sample where the retrospective changes are to be sought

minimum_distance

A real number between 0 and 1 corresponding to a lower-bound on the minimum normalized length of the stationary segments (as percentage of total sample length)

Value

The list of changepoints in order of score

References

khaleghi2012locatingRChest