Returns the position of changepoints in the sequence. NOTE: PyChest needs to be installed first by calling `install_PyChest'.
list_estimator(sample, minimum_distance)A vector of floats corresponding to the piecewise stationary sample where the retrospective changes are to be sought
A real number between 0 and 1 corresponding to a lower-bound on the minimum normalized length of the stationary segments (as percentage of total sample length)
The list of changepoints in order of score
khaleghi2012locatingRChest